@@ -1,5 +1,5 @@
 /*  zomghelper, an information extractor for Ogg Vorbis files
-    Copyright (C) 2005-2013  Clint Adams
+    Copyright (C) 2005-2014  Clint Adams
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -18,17 +18,53 @@
 #include <stdio.h>
 #include <math.h>
 
-#ifdef HAVE_VORBIS_VORBISFILE_H
-# include <vorbis/vorbisfile.h>
-#else
-# error install libvorbis-dev
-#endif
+#include <vorbis/vorbisfile.h>
+#include <opusfile.h>
+
+struct result {
+	int secs;
+	vorbis_comment *com;
+};
+
+void do_vorbis(OggVorbis_File *f, struct result *r) {
+	double k;
+
+	if (ov_test_open(f))
+		exit(4);
+
+	k = ov_time_total(f,-1);
+	if (k == OV_EINVAL)
+		exit(5);
+
+	r->com = ov_comment(f,-1);
+	if (r->com == NULL)
+		exit(6);
+
+	r->secs = (int)ceil(k);
+}
+
+void do_opus(OggOpusFile *f, struct result *r) {
+	ogg_int64_t k;
+
+	if (op_test_open(f))
+		exit(4);
+
+	k = op_pcm_total(f,-1);
+	if (k == OV_EINVAL)
+		exit(5);
+
+	r->com = (vorbis_comment *)op_tags(f,-1);
+	if (r->com == NULL)
+		exit(6);
+
+	r->secs = (int)(k / 48000);
+}
 
 int main(int argc, char **argv) {
 	FILE *f;
+	OggOpusFile *of;
 	OggVorbis_File vf;
-	double k;
-	vorbis_comment *com;
+	struct result r;
 	char **soc;
 
 	if (argc!=2)
@@ -38,23 +74,16 @@ int main(int argc, char **argv) {
 	if (f==NULL)
 		exit(2);
 
-	if (ov_test(f, &vf, NULL, 0))
+	if (!ov_test(f, &vf, NULL, 0))
+		do_vorbis(&vf, &r);
+	else if (of = op_test_file(argv[1], NULL))
+		do_opus(of, &r);
+	else
 		exit(3);
 
-	if (ov_test_open(&vf))
-		exit(4);
+	printf("ZOMGSECS: %d\n", r.secs);
 
-	k = ov_time_total(&vf,-1);
-	if (k == OV_EINVAL)
-		exit(5);
-
-	com = ov_comment(&vf,-1);
-	if (com == NULL)
-		exit(6);
-
-	printf("ZOMGSECS: %d\n", (int)ceil(k));
-
-	soc = com->user_comments;
+	soc = r.com->user_comments;
 
 	while(*(soc)) {
 		printf("%s\n", *soc++);
